#    Bitsquid Blender Tools
#    Copyright (C) 2021  Lucas Schwiderski
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

import os
import bpy
from bitsquid import step


template = """
parent_material = "core/stingray_renderer/shader_import/standard"

textures = {}

variables = {
    base_color = {
        type = "vector3"
        value = [
            1
            0.333333333333333
            0
        ]
    }
    emissive = {
        type = "vector3"
        value = [
            0
            0
            0
        ]
    }
    emissive_intensity = {
        type = "scalar"
        value = 1
    }
    metallic = {
        type = "scalar"
        value = 0
    }
    roughness = {
        type = "scalar"
        value = 0.91
    }
    use_ao_map = {
        type = "scalar"
        value = 0
    }
    use_color_map = {
        type = "scalar"
        value = 0
    }
    use_emissive_map = {
        type = "scalar"
        value = 0
    }
    use_metallic_map = {
        type = "scalar"
        value = 0
    }
    use_normal_map = {
        type = "scalar"
        value = 0
    }
    use_roughness_map = {
        type = "scalar"
        value = 0
    }
}

"""


def build_filepath(material):
    dir = bpy.path.abspath(material.bitsquid.material_filepath)
    return os.path.join(dir, "{}.material".format(material.name))


def save(self, context, material):
    filepath = build_filepath(material)
    self.report({'INFO'}, "Saving material to " + filepath)

    namespace = {
        'material': material,
    }
    content = step.Template(template).expand(namespace)

    self.report({'INFO'}, content)

    return {'FINISHED'}
