#    Bitsquid Blender Tools
#    Copyright (C) 2021  Lucas Schwiderski
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

import os
import bpy
from bpy_extras import io_utils
from bitsquid import step
from bitsquid.material import export as material_export

template = """
%if len(materials) > 0:
materials = {
    %for item in materials:
        {{ item['name'] }} = "{{ item['path'] }}"
    %endfor
}
%endif

renderables = {
    {{ object.name }} = {
        always_keep = false
        culling = "bounding_volume"
        generate_uv_unwrap = false
        occluder = false
        shadow_caster = true
        surface_queries = false
        viewport_visible = true
    }
}
"""


def build_filepath(object):
    dir = bpy.path.abspath(object.bitsquid.unit_filepath)
    return os.path.join(dir, "{}.unit".format(object.name))


def save(self, context, object):
    filepath = build_filepath(object)
    self.report({'INFO'}, "Saving unit to " + filepath)

    materials = []
    for material_slot in object.material_slots.values():
        materials.append({
            'name': material_slot.name,
            'path': material_export.build_filepath(material_slot.material),
        })

    namespace = {
        'object': object,
        'materials': materials,
    }
    content = step.Template(template).expand(namespace)

    self.report({'INFO'}, content)

    return {'FINISHED'}
